==> dl.php?src=linea21_2_5_0.zip: linea21/languages/en/lang_page.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['page']['section'] = "pages";

/*	nommage des modules
 *  	*/
$lang['page']['name']='page';
$lang['page']['confirm_add'] = "Page successfully added\n";
$lang['page']['confirm_mod'] = "Page successfully updated\n";
$lang['page']['confirm_sup'] ="Page successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['page']['add']= 'Add new '.$lang['page']['name'];
$lang['page']['mod']= 'Edit '.$lang['page']['name'];
$lang['page']['sup']= 'Delete '.$lang['page']['name'];
$lang['page']['det']= ucfirst($lang['page']['name']). ' details';
$lang['page']['list']= 'See pages';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['page']['add_title']='Enter new '.$lang['page']['name'].' data';
$lang['page']['mod_title']='Edit '.$lang['page']['name'].' data';
$lang['page']['recap_commment']='no comments';


/*	check integrité des données
 *  	*/
$lang['page']['no_title']='Title is required';
$lang['page']['no_body']='Body is required';
$lang['page']['no_header']='Header is required';



/*	nommage élément rubrique
 *  	*/
$lang['page']['title']='title';
$lang['page']['header']= 'header';
$lang['page']['body']= 'body';
$lang['page']['heading']= 'heading';
$lang['page']['heading_info']= 'heading text for given element';
$lang['page']['public-url']= 'public URL';
$lang['page']['is_homepage']='homepage';
$lang['page']['statut']='publication status';
$lang['page']['author']='author';



/*	nommage quickbox
 *  	*/
$lang['page']['qb_titleadd']=' latest additions';
$lang['page']['qb_titlemod']=' latest modifications';
$lang['page']['qb_titlesup']=' latest deletions';
$lang['page']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['page']['nb_total']='pages in database.';
$lang['page']['statut_filter']='Show by status';
$lang['page']['all']='Show list';
$lang['page']['noresult']='There is no page matching this criteria ';


/*	public
 *  	*/
$lang['page']['name2']='pages';

/*	rubrique d'aide
 *  	*/
$lang['page']['help_add1']='To add a page, please insert the required information in the form above';
$lang['page']['help_add2']='After submitting the form, check your data in the summary';
$lang['page']['help_add3']='If you are not satisfied with the summary, click the \'review settings\' button to make new changes';


$lang['page']['help_list1']='Click on a page\'s title to show its details';
$lang['page']['help_list2']='Delete a page by clicking on the associated delete icon';
$lang['page']['help_list3']='Edit page by clicking on the associated edit icon';
$lang['page']['help_list4']='Filter by status to display pages for a given status';
$lang['page']['help_list5']='Click the \'add page\' button in the header to add a page';
$lang['page']['help_list6']="To search pages only, just click 'search'";


$lang['page']['help_mod1']='You can edit all accessible fields in the form above';
$lang['page']['help_mod2']='After submitting the form, check your data in the summary';
$lang['page']['help_mod3']='If you are not satisfied with the summary, click the \'review settings\' button to make new changes';


$lang['page']['help_det1']='Delete this page by clicking on the associated delete icon';
$lang['page']['help_det2']='Edit this page by clicking on the associated edit icon';

$lang['page']['help_sup1']='Click \'cancel\' to abort deletion';
?>

==> dl.php?src=linea21_2_8_0.zip: linea21/languages/en/lang_page.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - Simon Georget <simon@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['page']['section'] = "pages";

/*	nommage des modules
 *  	*/
$lang['page']['name']='page';
$lang['page']['confirm_add'] = "Page successfully added\n";
$lang['page']['confirm_mod'] = "Page successfully updated\n";
$lang['page']['confirm_sup'] ="Page successfully deleted\n";


/*	nommage rubrique module
 *  	*/
$lang['page']['add']= 'Add new '.$lang['page']['name'];
$lang['page']['mod']= 'Edit '.$lang['page']['name'];
$lang['page']['sup']= 'Delete '.$lang['page']['name'];
$lang['page']['det']= ucfirst($lang['page']['name']). ' details';
$lang['page']['list']= 'See pages';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['page']['add_title']='Enter new '.$lang['page']['name'].' data';
$lang['page']['mod_title']='Edit '.$lang['page']['name'].' data';
$lang['page']['recap_commment']='no comments';


/*	check integrité des données
 *  	*/
$lang['page']['no_title']='Title is required';
$lang['page']['no_body']='Body is required';
$lang['page']['no_header']='Header is required';



/*	nommage élément rubrique
 *  	*/
$lang['page']['title']='title';
$lang['page']['header']= 'header';
$lang['page']['body']= 'body';
$lang['page']['heading']= 'heading';
$lang['page']['heading_info']= 'Make this page heading text for choosen element - Content field only will be displayed';
$lang['page']['public-url']= 'public URL';
$lang['page']['is_homepage']='homepage';
$lang['page']['statut']='publication status';
$lang['page']['author']='author';



/*	nommage quickbox
 *  	*/
$lang['page']['qb_titleadd']=' latest additions';
$lang['page']['qb_titlemod']=' latest modifications';
$lang['page']['qb_titlesup']=' latest deletions';
$lang['page']['qb_titlepubli']=' latest publications';


/*	divers
 *  	*/
$lang['page']['nb_total']='pages in database.';
$lang['page']['statut_filter']='Show by status';
$lang['page']['all']='Show list';
$lang['page']['noresult']='There is no page matching this criteria ';


/*	public
 *  	*/
$lang['page']['name2']='pages';

/*	rubrique d'aide
 *  	*/
$lang['page']['help_add1']='To add a page, please insert the required information in the form above';
$lang['page']['help_add2']='After submitting the form, check your data in the summary';
$lang['page']['help_add3']='If you are not satisfied with the summary, click the \'review settings\' button to make new changes';


$lang['page']['help_list1']='Click on a page\'s title to show its details';
$lang['page']['help_list2']='Delete a page by clicking on the associated delete icon';
$lang['page']['help_list3']='Edit page by clicking on the associated edit icon';
$lang['page']['help_list4']='Filter by status to display pages for a given status';
$lang['page']['help_list5']='Click the \'add page\' button in the header to add a page';
$lang['page']['help_list6']="To search pages only, just click 'search'";


$lang['page']['help_mod1']='You can edit all accessible fields in the form above';
$lang['page']['help_mod2']='After submitting the form, check your data in the summary';
$lang['page']['help_mod3']='If you are not satisfied with the summary, click the \'review settings\' button to make new changes';


$lang['page']['help_det1']='Delete this page by clicking on the associated delete icon';
$lang['page']['help_det2']='Edit this page by clicking on the associated edit icon';

$lang['page']['help_sup1']='Click \'cancel\' to abort deletion';
?>
